==> saods9_7.0.1+dfsg.orig.tar.gz: saods9/src/source.tcl <==
#  Copyright (C) 1999-2012
#  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
#  For conditions of distribution and use, see copyright notice in "copyright"

package provide DS9 1.0

source $ds9(root)/src/2mass.tcl
source $ds9(root)/src/3d.tcl
source $ds9(root)/src/array.tcl
source $ds9(root)/src/analysis.tcl
source $ds9(root)/src/analysisparam.tcl
source $ds9(root)/src/annulus.tcl
source $ds9(root)/src/ar.tcl
source $ds9(root)/src/backup.tcl
source $ds9(root)/src/bin.tcl
source $ds9(root)/src/box.tcl
source $ds9(root)/src/boxannulus.tcl
source $ds9(root)/src/bpanda.tcl
source $ds9(root)/src/buttons.tcl
source $ds9(root)/src/cat.tcl
source $ds9(root)/src/catcds.tcl
source $ds9(root)/src/catcdssrch.tcl
source $ds9(root)/src/catcdssrchdialog.tcl
source $ds9(root)/src/catcmd.tcl
source $ds9(root)/src/catdialog.tcl
source $ds9(root)/src/cattsv.tcl
source $ds9(root)/src/catcxc.tcl
source $ds9(root)/src/catflt.tcl
source $ds9(root)/src/catned.tcl
source $ds9(root)/src/catopt.tcl
source $ds9(root)/src/catreg.tcl
source $ds9(root)/src/catsdss.tcl
source $ds9(root)/src/catsimbad.tcl
source $ds9(root)/src/catskybot.tcl
source $ds9(root)/src/catsym.tcl
source $ds9(root)/src/catvot.tcl
source $ds9(root)/src/centroid.tcl
source $ds9(root)/src/circle.tcl
source $ds9(root)/src/colorbar.tcl
source $ds9(root)/src/comm.tcl
source $ds9(root)/src/command.tcl
source $ds9(root)/src/compass.tcl
source $ds9(root)/src/composite.tcl
source $ds9(root)/src/contour.tcl
source $ds9(root)/src/convert.tcl
source $ds9(root)/src/coord.tcl
source $ds9(root)/src/cpanda.tcl
source $ds9(root)/src/crop.tcl
source $ds9(root)/src/crosshair.tcl
source $ds9(root)/src/cube.tcl
source $ds9(root)/src/debug.tcl
source $ds9(root)/src/dialog.tcl
source $ds9(root)/src/ellipse.tcl
source $ds9(root)/src/ellipseannulus.tcl
source $ds9(root)/src/epanda.tcl
source $ds9(root)/src/error.tcl
source $ds9(root)/src/eso.tcl
source $ds9(root)/src/examine.tcl
source $ds9(root)/src/export.tcl
source $ds9(root)/src/external.tcl
source $ds9(root)/src/fits.tcl
source $ds9(root)/src/first.tcl
source $ds9(root)/src/frame.tcl
source $ds9(root)/src/graph.tcl
source $ds9(root)/src/grid.tcl
source $ds9(root)/src/group.tcl
source $ds9(root)/src/header.tcl
source $ds9(root)/src/help.tcl
source $ds9(root)/src/http.tcl
source $ds9(root)/src/hv.tcl
source $ds9(root)/src/hvform.tcl
source $ds9(root)/src/hvsup.tcl
source $ds9(root)/src/iis.tcl
source $ds9(root)/src/imexam.tcl
source $ds9(root)/src/imgsvr.tcl
source $ds9(root)/src/info.tcl
source $ds9(root)/src/layout.tcl
source $ds9(root)/src/line.tcl
source $ds9(root)/src/load.tcl
source $ds9(root)/src/magnifier.tcl
source $ds9(root)/src/marker.tcl
source $ds9(root)/src/markeranalysisplot2d.tcl
source $ds9(root)/src/markeranalysisplot3d.tcl
source $ds9(root)/src/markerbase.tcl
source $ds9(root)/src/markerbaseannulus.tcl
source $ds9(root)/src/markerbaseannulusrect.tcl
source $ds9(root)/src/markerbasecenter.tcl
source $ds9(root)/src/markerbaseline.tcl
source $ds9(root)/src/markerbasepanda.tcl
source $ds9(root)/src/markerbasepandarect.tcl
source $ds9(root)/src/markerdialog.tcl
source $ds9(root)/src/mask.tcl
source $ds9(root)/src/manalysis.tcl
source $ds9(root)/src/mbin.tcl
source $ds9(root)/src/mcolor.tcl
source $ds9(root)/src/medit.tcl
source $ds9(root)/src/menu.tcl
source $ds9(root)/src/mfile.tcl
source $ds9(root)/src/mframe.tcl
source $ds9(root)/src/mhelp.tcl
source $ds9(root)/src/movie.tcl
source $ds9(root)/src/mregion.tcl
source $ds9(root)/src/mscale.tcl
source $ds9(root)/src/mview.tcl
source $ds9(root)/src/mwcs.tcl
source $ds9(root)/src/mzoom.tcl
source $ds9(root)/src/nameres.tcl
source $ds9(root)/src/nsvr.tcl
source $ds9(root)/src/nvss.tcl
source $ds9(root)/src/pagesetup.tcl
source $ds9(root)/src/panner.tcl
source $ds9(root)/src/panzoom.tcl
source $ds9(root)/src/pixel.tcl
source $ds9(root)/src/photo.tcl
source $ds9(root)/src/plot.tcl
source $ds9(root)/src/plotsup.tcl
source $ds9(root)/src/point.tcl
source $ds9(root)/src/polygon.tcl
source $ds9(root)/src/prefs.tcl
source $ds9(root)/src/prefsdialog.tcl
source $ds9(root)/src/print.tcl
source $ds9(root)/src/projection.tcl
source $ds9(root)/src/rgb.tcl
source $ds9(root)/src/ruler.tcl
source $ds9(root)/src/samp.tcl
source $ds9(root)/src/sao.tcl
source $ds9(root)/src/savefits.tcl
source $ds9(root)/src/saveimage.tcl
source $ds9(root)/src/scale.tcl
source $ds9(root)/src/skyview.tcl
source $ds9(root)/src/slider.tcl
source $ds9(root)/src/smooth.tcl
source $ds9(root)/src/starbase.tcl
source $ds9(root)/src/stdfbox.tcl
source $ds9(root)/src/stsci.tcl
source $ds9(root)/src/template.tcl
source $ds9(root)/src/text.tcl
source $ds9(root)/src/tkfbox.tcl
source $ds9(root)/src/util.tcl
source $ds9(root)/src/vector.tcl
source $ds9(root)/src/vo.tcl
source $ds9(root)/src/wcs.tcl
source $ds9(root)/src/xmfbox.tcl
source $ds9(root)/src/xpa.tcl

switch [tk windowingsystem] {
    x11 {}
    win32 {source $ds9(root)/src/win32.tcl}
    aqua {source $ds9(root)/src/macosx.tcl}
}

==> saods9_7.1+dfsg.orig.tar.gz: saods9/src/source.tcl <==
#  Copyright (C) 1999-2012
#  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
#  For conditions of distribution and use, see copyright notice in "copyright"

package provide DS9 1.0

source $ds9(root)/src/2mass.tcl
source $ds9(root)/src/3d.tcl
source $ds9(root)/src/array.tcl
source $ds9(root)/src/analysis.tcl
source $ds9(root)/src/analysisparam.tcl
source $ds9(root)/src/annulus.tcl
source $ds9(root)/src/ar.tcl
source $ds9(root)/src/backup.tcl
source $ds9(root)/src/bin.tcl
source $ds9(root)/src/box.tcl
source $ds9(root)/src/boxannulus.tcl
source $ds9(root)/src/bpanda.tcl
source $ds9(root)/src/buttons.tcl
source $ds9(root)/src/cat.tcl
source $ds9(root)/src/catcds.tcl
source $ds9(root)/src/catcdssrch.tcl
source $ds9(root)/src/catcdssrchdialog.tcl
source $ds9(root)/src/catcmd.tcl
source $ds9(root)/src/catcxc.tcl
source $ds9(root)/src/catdialog.tcl
source $ds9(root)/src/catflt.tcl
source $ds9(root)/src/catmatch.tcl
source $ds9(root)/src/catned.tcl
source $ds9(root)/src/catopt.tcl
source $ds9(root)/src/catplot.tcl
source $ds9(root)/src/catreg.tcl
source $ds9(root)/src/catsdss.tcl
source $ds9(root)/src/catsimbad.tcl
source $ds9(root)/src/catskybot.tcl
source $ds9(root)/src/catsym.tcl
source $ds9(root)/src/cattsv.tcl
source $ds9(root)/src/catvot.tcl
source $ds9(root)/src/centroid.tcl
source $ds9(root)/src/circle.tcl
source $ds9(root)/src/colorbar.tcl
source $ds9(root)/src/comm.tcl
source $ds9(root)/src/command.tcl
source $ds9(root)/src/compass.tcl
source $ds9(root)/src/composite.tcl
source $ds9(root)/src/contour.tcl
source $ds9(root)/src/convert.tcl
source $ds9(root)/src/coord.tcl
source $ds9(root)/src/cpanda.tcl
source $ds9(root)/src/crop.tcl
source $ds9(root)/src/crosshair.tcl
source $ds9(root)/src/cube.tcl
source $ds9(root)/src/debug.tcl
source $ds9(root)/src/dialog.tcl
source $ds9(root)/src/ellipse.tcl
source $ds9(root)/src/ellipseannulus.tcl
source $ds9(root)/src/epanda.tcl
source $ds9(root)/src/error.tcl
source $ds9(root)/src/eso.tcl
source $ds9(root)/src/examine.tcl
source $ds9(root)/src/export.tcl
source $ds9(root)/src/external.tcl
source $ds9(root)/src/fits.tcl
source $ds9(root)/src/first.tcl
source $ds9(root)/src/frame.tcl
source $ds9(root)/src/graph.tcl
source $ds9(root)/src/grid.tcl
source $ds9(root)/src/group.tcl
source $ds9(root)/src/header.tcl
source $ds9(root)/src/help.tcl
source $ds9(root)/src/http.tcl
source $ds9(root)/src/hv.tcl
source $ds9(root)/src/hvform.tcl
source $ds9(root)/src/hvsup.tcl
source $ds9(root)/src/iis.tcl
source $ds9(root)/src/imexam.tcl
source $ds9(root)/src/imgsvr.tcl
source $ds9(root)/src/info.tcl
source $ds9(root)/src/layout.tcl
source $ds9(root)/src/line.tcl
source $ds9(root)/src/load.tcl
source $ds9(root)/src/magnifier.tcl
source $ds9(root)/src/marker.tcl
source $ds9(root)/src/markeranalysispanda.tcl
source $ds9(root)/src/markeranalysisplot2d.tcl
source $ds9(root)/src/markeranalysisplot3d.tcl
source $ds9(root)/src/markeranalysisradial.tcl
source $ds9(root)/src/markeranalysisstats.tcl
source $ds9(root)/src/markerbase.tcl
source $ds9(root)/src/markerbaseannulus.tcl
source $ds9(root)/src/markerbaseannulusrect.tcl
source $ds9(root)/src/markerbasecenter.tcl
source $ds9(root)/src/markerbaseline.tcl
source $ds9(root)/src/markerbasepanda.tcl
source $ds9(root)/src/markerbasepandarect.tcl
source $ds9(root)/src/markerdialog.tcl
source $ds9(root)/src/mask.tcl
source $ds9(root)/src/manalysis.tcl
source $ds9(root)/src/mbin.tcl
source $ds9(root)/src/mcolor.tcl
source $ds9(root)/src/medit.tcl
source $ds9(root)/src/menu.tcl
source $ds9(root)/src/mfile.tcl
source $ds9(root)/src/mframe.tcl
source $ds9(root)/src/mhelp.tcl
source $ds9(root)/src/movie.tcl
source $ds9(root)/src/mregion.tcl
source $ds9(root)/src/mscale.tcl
source $ds9(root)/src/mview.tcl
source $ds9(root)/src/mwcs.tcl
source $ds9(root)/src/mzoom.tcl
source $ds9(root)/src/nameres.tcl
source $ds9(root)/src/nsvr.tcl
source $ds9(root)/src/nvss.tcl
source $ds9(root)/src/pagesetup.tcl
source $ds9(root)/src/panner.tcl
source $ds9(root)/src/panzoom.tcl
source $ds9(root)/src/pixel.tcl
source $ds9(root)/src/photo.tcl
source $ds9(root)/src/plot.tcl
source $ds9(root)/src/plotbar.tcl
source $ds9(root)/src/plotdialog.tcl
source $ds9(root)/src/plotelement.tcl
source $ds9(root)/src/plotline.tcl
source $ds9(root)/src/plotprint.tcl
source $ds9(root)/src/plotprocess.tcl
source $ds9(root)/src/plotscatter.tcl
source $ds9(root)/src/point.tcl
source $ds9(root)/src/polygon.tcl
source $ds9(root)/src/prefs.tcl
source $ds9(root)/src/prefsdialog.tcl
source $ds9(root)/src/print.tcl
source $ds9(root)/src/projection.tcl
source $ds9(root)/src/rgb.tcl
source $ds9(root)/src/ruler.tcl
source $ds9(root)/src/samp.tcl
source $ds9(root)/src/sao.tcl
source $ds9(root)/src/savefits.tcl
source $ds9(root)/src/saveimage.tcl
source $ds9(root)/src/scale.tcl
source $ds9(root)/src/skyview.tcl
source $ds9(root)/src/slider.tcl
source $ds9(root)/src/smooth.tcl
source $ds9(root)/src/starbase.tcl
source $ds9(root)/src/stdfbox.tcl
source $ds9(root)/src/stsci.tcl
source $ds9(root)/src/template.tcl
source $ds9(root)/src/text.tcl
source $ds9(root)/src/tkfbox.tcl
source $ds9(root)/src/util.tcl
source $ds9(root)/src/vector.tcl
source $ds9(root)/src/vo.tcl
source $ds9(root)/src/wcs.tcl
source $ds9(root)/src/xmfbox.tcl
source $ds9(root)/src/xpa.tcl

switch [tk windowingsystem] {
    x11 {}
    win32 {source $ds9(root)/src/win32.tcl}
    aqua {source $ds9(root)/src/macosx.tcl}
}
